# Neutron Sync

A command line utility to sync your personal dotfiles to an encrypted Github. This allows you to share your personal secrets across multiple machines and keep them in sync.

## Installation

`pipx install neutron-sync`

*[See pipx](https://pypa.github.io/pipx/)*
